Method: Kuapir::ImageResponse#initialize
- Defined in:
- lib/kuapir/models/image_response.rb
#initialize(attributes = {}) ⇒ ImageResponse
Initializes the object
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/kuapir/models/image_response.rb', line 46 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Kuapir::ImageResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Kuapir::ImageResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end self.total = attributes[:total] if attributes.key?(:total) self.total_pages = attributes[:total_pages] if attributes.key?(:total_pages) if attributes.key?(:items) && (value = attributes[:items]).is_a?(Array) self.items = value end end |